@@ -24,19 +24,23 @@ return array(
 				'image' => 'icons/user_add.png',
 				'fields' => array(
 					'ftp_username' => array(
-						'visible' => ($settings['customer']['ftpatdomain'] == '1' ? true : false),
+						'visible' => (Settings::Get('customer.ftpatdomain') == '1' ? true : false),
 						'label' => $lng['login']['username'],
 						'type' => 'text'
 					),
 					'ftp_domain' => array(
-						'visible' => ($settings['customer']['ftpatdomain'] == '1' ? true : false),
+						'visible' => (Settings::Get('customer.ftpatdomain') == '1' ? true : false),
 						'label' => $lng['domains']['domainname'],
 						'type' => 'select',
 						'select_var' => (isset($domains) ? $domains : ""),
 					),
+					'ftp_description' => array(
+						'label' => $lng['panel']['ftpdesc'] = 'FTP description',
+						'type' => 'text'
+					),
 					'path' => array(
 						'label' => $lng['panel']['path'],
-						'desc' => ($settings['panel']['pathedit'] != 'Dropdown' ? $lng['panel']['pathDescription'] : null).(isset($pathSelect['note']) ? '<br />'.$pathSelect['value'] : ''),
+						'desc' => (Settings::Get('panel.pathedit') != 'Dropdown' ? $lng['panel']['pathDescription'] : null).(isset($pathSelect['note']) ? '<br />'.$pathSelect['value'] : ''),
 						'type' => $pathSelect['type'],
 						'select_var' => $pathSelect['value'],
 						'value' => $pathSelect['value']
@@ -49,6 +53,7 @@ return array(
 					'ftp_password_suggestion' => array(
 						'label' => $lng['customer']['generated_pwd'],
 						'type' => 'text',
+						'visible' => (Settings::Get('panel.password_regex') == ''),
 						'value' => generatePassword(),
 					),
 					'sendinfomail' => array(
@@ -59,6 +64,12 @@ return array(
 									),
 						'value' => array()
 					),
+					'shell' => array(
+						'visible' => (Settings::Get('system.allow_customer_shell') == '1' ? true : false),
+						'label' => $lng['panel']['shell'],
+						'type' => 'select',
+						'select_var' => (isset($shells) ? $shells : ""),
+					)
 				)
 			)
 		)
